@@ -34,6 +34,8 @@ no warnings 'redefine';
 
 require 5.005_62;
 
+use Carp;
+
 require Exporter;
 
 our @ISA = qw(Exporter);
@@ -54,7 +56,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw(
 
 );
-our $VERSION = '2.05';
+our $VERSION = '2.07';
 
 # -----------------------------------------------
 
@@ -263,13 +265,13 @@ __END__
 
 =head1 NAME
 
-C<DBIx::Admin::TableInfo> - A wrapper for all of table_info(), column_info(), *_key_info()
+DBIx::Admin::TableInfo - A wrapper for all of table_info(), column_info(), *_key_info()
 
 =head1 Synopsis
 
 This program is shipped as examples/table.info.pl.
 
-	#!/usr/bin/perl
+	#!/usr/bin/env perl
 
 	use strict;
 	use warnings;
@@ -676,7 +678,7 @@ See the examples/ directory in the distro.
 
 =head1 Tested Database Formats
 
-The first set of tests was done with C<DBIx::Admin::TableInfo> up to V 2.03, 
+The first set of tests was done with C<DBIx::Admin::TableInfo> up to V 2.03,
 using examples/table.info.pl (as per the Synopsis):
 
 =over 4
